<?php

namespace Drupal\martelus_companion\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'MartelusCompanionBlock' block.
 *
 * @Block(
 *  id = "martelus_companion_block",
 *  admin_label = @Translation("MartelusCompanion"),
 * )
 */
class MartelusCompanionBlock extends BlockBase {

  /**
   * Defines the configuration object factory.
   *
   * @var Drupal\Core\Config\ConfigFactory
   */
  protected $config;

  /**
   * Provides a create block.
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory')
    );
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    $config = $this->getConfiguration();

    $form['markup1'] = [
      '#type' => 'markup',
      '#markup' => '
        <div class="btn-group">
          <a href="https://martelus.store/plans-and-pricing" target="_blank" class="btn-martelus-store">Don\'t have an account? Create one now!</a>
        </div>
        <p class="welcome-message">
          The Martelus Companion interacts with users according to instructions you provide in the prompt on your Martelus account dashboard. Users will be able to speak with the bot in either voice or text mode.<br>
To get started, you need to enter your Martelus Account ID. You can find your account id under settings on your Martelus account dashboard.
        </p>
      ',
    ];

    $form['accountid'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Account ID'),
      '#placeholder' => '266626f8-f175-447f-9683-c386b3ef9d2b ',
      '#description' => $this->t('Use your account ID to enable your bot.'),
      '#default_value' => $config['accountid'],
    ];

    $form['markup6'] = [
      '#type' => 'markup',
      '#markup' => '
        </div>
      ',
    ];
    $form['markup7'] = [
      '#type' => 'markup',
      '#markup' => '
        </div>
      ',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    $this->setConfigurationValue('accountid', $form_state->getValue('accountid'));
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->getConfiguration();

    $items = [];
    $items['accountid'] = $config['accountid'];
    $renderable = [
      '#theme' => 'martelus-companion',
      '#content' => $items,
    ];

    return $renderable;
  }

}
